==> igloo_0_1_5.zip: igloo_0_1_5/igloo/language/1/barnraiser_01/my_bookmarks.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_schedule'] = 						"schedule items";
$lang['hdr_library'] = 							"wiki pages";
$lang['hdr_my_bookmark'] = 						"removing marks and tips";
$lang['hdr_recommended'] = 						"tips";
$lang['hdr_subjects'] = 						"discussion subjects";
$lang['hdr_watching'] = 						"marks";
$lang['hdr_polls'] = 							"polls";


//A HREF TAGS (links)
$lang['href_watching'] =						"marks &amp; tips";


//BODY TEXT
$lang['txt_delete_bookmark'] =					"To delete marks or tips check the box next to each item that you want to delete and then press the 'delete' button.";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";

?>

==> igloo_0_1_6.zip: igloo_0_1_6/igloo/language/1/barnraiser_01/my_bookmarks.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');


//HEADER
$lang['hdr_blogs'] = 							"blogs";
$lang['hdr_schedule'] = 						"schedule items";
$lang['hdr_library'] = 							"wiki pages";
$lang['hdr_my_bookmark'] = 						"removing marks and tips";
$lang['hdr_recommended'] = 						"tips";
$lang['hdr_subjects'] = 						"discussion subjects";
$lang['hdr_watching'] = 						"marks";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_notify'] = 							"tracking an item (email notification)";


//A HREF TAGS (links)
$lang['href_watching'] =						"marks &amp; tips";
$lang['href_track'] =							"track";
$lang['href_untrack'] =							"remove tracking";


//BODY TEXT
$lang['txt_delete_bookmark'] =					"To delete marks or tips check the box next to each item that you want to delete and then press the 'delete' button.";
$lang['txt_movement'] = 						"movement";
$lang['txt_lastview'] = 						"last viewed";
$lang['txt_notify'] = 							"you can request an email to be sent to you when an item receives a new comment. This is called tracking and you can activiate it using the 'track'. Once activated you can always return here and 'remove tracker' to stop emails being sent to you.";

?>
